@@ -2,6 +2,11 @@
 # copyright (C) 1994-9 W. N. Venables and B. D. Ripley
 #
 
+con2tr <- function(obj)
+{
+    data.frame(expand.grid(x=obj$x,y=obj$y),z=as.vector(obj$z))
+}
+
 Null <- function(M)
 {
     tmp <- qr(M)
@@ -24,3 +29,10 @@ ginv <- function(X, tol = sqrt(.Machine$double.eps))
     else if(!any(Positive)) array(0, dim(X)[2:1])
     else Xsvd$v[, Positive, drop=FALSE] %*% ((1/Xsvd$d[Positive]) * t(Xsvd$u[, Positive, drop=FALSE]))
 }
+
+
+if(R.version$major == "1" && R.version$minor < "5.0") {
+rowSums <- function(x) apply(x, 1, sum)
+colSums <- function(x) apply(x, length(dim(x)), sum)
+colMeans <- function(x) apply(x, length(dim(x)), mean)
+}
